@@ -1,4 +1,4 @@
-/* $Id: email_conduit.c,v 1.17 2002/09/16 17:16:22 jpr Exp $ */
+/* $Id: email_conduit.c,v 1.18 2003/01/26 22:29:20 toshok Exp $ */
 
 #include <glib.h>
 #include <gnome.h>
@@ -633,7 +633,7 @@ handleFileSelector (GtkWidget *widget, gpointer data)
 {
     GtkWidget *fs = data;
     GtkWidget *entry = GTK_WIDGET(gtk_object_get_data(GTK_OBJECT(fs), "entry"));
-    gchar *fname;
+    const gchar *fname;
 
     fname = gtk_file_selection_get_filename (GTK_FILE_SELECTION(fs));
     gtk_entry_set_text(GTK_ENTRY(entry), fname);
@@ -898,18 +898,10 @@ GnomePilotConduit *conduit_get_gpilot_conduit( guint32 pilotId )
   gtk_signal_connect(retval, "synchronize", (GtkSignalFunc)synchronize ,NULL);
 
   /* GUI signals */
-  gtk_signal_connect (retval, 
-          GNOME_PILOT_CONDUIT_SIGNAL_CREATE_SETTINGS_WINDOW (create_settings_window), 
-          NULL);
-  gtk_signal_connect (retval, 
-	  GNOME_PILOT_CONDUIT_SIGNAL_DISPLAY_SETTINGS (display_settings), 
-	  NULL);
-  gtk_signal_connect (retval, 
-	  GNOME_PILOT_CONDUIT_SIGNAL_SAVE_SETTINGS (save_settings), 
-	  NULL);
-  gtk_signal_connect (retval, 
-	  GNOME_PILOT_CONDUIT_SIGNAL_REVERT_SETTINGS (revert_settings), 
-	  NULL);
+  gtk_signal_connect(retval, "create_settings_window", (GtkSignalFunc)create_settings_window ,NULL);
+  gtk_signal_connect(retval, "display_settings", (GtkSignalFunc)display_settings ,NULL);
+  gtk_signal_connect(retval, "save_settings", (GtkSignalFunc)save_settings ,NULL);
+  gtk_signal_connect(retval, "revert_settings", (GtkSignalFunc)revert_settings ,NULL);
 
   load_configuration(&cfg1, pilotId );
   cfg2 = dupe_configuration(cfg1);
